[kaffe] CVS kaffe (mkoch): libraries/javalib/javax/swing/JTable.java

Kaffe CVS cvs-commits at kaffe.org
Thu Dec 16 08:14:26 PST 2004


PatchSet 5649 
Date: 2004/12/16 16:09:58
Author: mkoch
Branch: HEAD
Tag: (none) 
Log:
2004-12-16  Michael Koch  <konqueror at gmx.de>

	* libraries/javalib/javax/swing/JTable.java
	(getIntercellSpacing): Fixed typo in method name.
	(setIntercellSpacing): Likewise.

Members: 
	ChangeLog:1.3194->1.3195 
	libraries/javalib/javax/swing/JTable.java:1.8->1.9 

Index: kaffe/ChangeLog
diff -u kaffe/ChangeLog:1.3194 kaffe/ChangeLog:1.3195
--- kaffe/ChangeLog:1.3194	Thu Dec 16 15:54:43 2004
+++ kaffe/ChangeLog	Thu Dec 16 16:09:58 2004
@@ -1,5 +1,11 @@
 2004-12-16  Michael Koch  <konqueror at gmx.de>
 
+	* libraries/javalib/javax/swing/JTable.java
+	(getIntercellSpacing): Fixed typo in method name.
+	(setIntercellSpacing): Likewise.
+
+2004-12-16  Michael Koch  <konqueror at gmx.de>
+
 	* libraries/javalib/javax/swing/text/JTextComponent.java
 	(focusAccelerator): New variable.
 	(getFocusAccelerator): New method.
Index: kaffe/libraries/javalib/javax/swing/JTable.java
diff -u kaffe/libraries/javalib/javax/swing/JTable.java:1.8 kaffe/libraries/javalib/javax/swing/JTable.java:1.9
--- kaffe/libraries/javalib/javax/swing/JTable.java:1.8	Sat Nov 13 02:17:44 2004
+++ kaffe/libraries/javalib/javax/swing/JTable.java	Thu Dec 16 16:10:02 2004
@@ -1003,11 +1003,11 @@
   }
 
   /**
    * Get the value of the {@link #interCellSpacing} property.
    *
    * @return The current value of the property
    */
-  public Dimension getInterCellSpacing()
+  public Dimension getIntercellSpacing()
   {
     return new Dimension(columnModel.getColumnMargin(), rowMargin);
   }
@@ -1297,11 +1297,11 @@
   }
 
   /**
    * Set the value of the {@link #interCellSpacing} property.
    *
    * @param i The new value of the interCellSpacing property
    */ 
-  public void setInterCellSpacing(Dimension i)
+  public void setIntercellSpacing(Dimension i)
   {
     rowMargin = i.height;
     columnModel.setColumnMargin(i.width);
@@ -1003,11 +1003,11 @@
 
   /**
-   * Get the value of the {@link #interCellSpacing} property.
+   * Get the value of the {@link #intercellSpacing} property.
    *
    * @return The current value of the property
@@ -1297,11 +1297,11 @@
 
   /**
-   * Set the value of the {@link #interCellSpacing} property.
+   * Set the value of the {@link #intercellSpacing} property.
    *
@@ -1297,11 +1297,11 @@
    *
-   * @param i The new value of the interCellSpacing property
+   * @param i The new value of the intercellSpacing property
    */ 




More information about the kaffe mailing list